@@ -8,7 +8,7 @@ use Logging::Simple;
 use Test::BrewBuild::BrewCommands;
 use Plugin::Simple default => 'Test::BrewBuild::Plugin::DefaultExec';
 
-our $VERSION = '1.00';
+our $VERSION = '1.03_01';
 
 my $log;
 my $bcmd;
@@ -25,14 +25,14 @@ sub new {
 
     my $plugin = $args{plugin} ? $args{plugin} : $ENV{TBB_PLUGIN};
 
-    $log->_7("plugin param set to: " . defined $plugin ? $plugin : 'default');
+    $log->_6("plugin param set to: " . defined $plugin ? $plugin : 'default');
 
     $plugin = $self->plugins($plugin, can => ['brewbuild_exec']);
 
     my $exec_plugin_sub = $plugin .'::brewbuild_exec';
     $self->{exec_plugin} = \&$exec_plugin_sub;
 
-    $log->_7("using plugin $plugin");
+    $log->_5("successfully loaded $plugin plugin");
 
     return $self;
 }
@@ -60,23 +60,23 @@ sub instance_remove {
 
     my $log = $log->child('instance_remove');
 
-    $log->_5("perls installed: " . join ', ', @perls_installed);
-    $log->_5("removing previous installs...");
+    $log->_7("perls installed: " . join ', ', @perls_installed);
+    $log->_0("removing previous installs...");
 
     my $remove_cmd = $bcmd->remove;
 
-    $log->_7("using $remove_cmd remove command");
+    $log->_5("using $remove_cmd remove command");
 
     for (@perls_installed){
         my $ver = $^V;
         $ver =~ s/v//;
 
         if ($_ =~ /$ver$/){
-            $log->_5("skipping version we're using, $_");
+            $log->_6("skipping version we're using, $_");
             next;
         }
 
-        $log->_7("exec'ing $remove_cmd");
+        $log->_6("exec'ing $remove_cmd");
 
         if ($bcmd->is_win) {
             `$remove_cmd $_ 2>nul`;
@@ -101,7 +101,7 @@ sub instance_install {
     if ($self->{args}{version}->[0]){
         for my $version (@{ $self->{args}{version} }){
             if (grep { $version eq $_ } @{ $perls_installed }){
-                $log->_5("$version is already installed... skipping");
+                $log->_7("$version is already installed... skipping");
                 next;
             }
             push @new_installs, $version;
@@ -110,14 +110,14 @@ sub instance_install {
     else {
         if ($new){
 
-            $log->_7("looking to install $new perl instance(s)");
+            $log->_6("looking to install $new perl instance(s)");
 
             while ($new > 0){
 
                 my $candidate = $perls_available->[rand @{ $perls_available }];
 
                 if (grep { $_ eq $candidate } @{ $perls_installed }) {
-                    $log->_5( "$candidate already installed... skipping" );
+                    $log->_7( "$candidate already installed... skipping" );
                     next;
                 }
 
@@ -132,12 +132,12 @@ sub instance_install {
 
         for my $ver (@new_installs){
             $log->_0("installing $ver...");
-            $log->_7("...using cmd: $install_cmd");
+            $log->_6("...using cmd: $install_cmd");
             `$install_cmd $ver`;
         }
     }
     else {
-        $log->_5("using existing versions only");
+        $log->_6("using existing versions only");
     }
 }
 sub results {
@@ -151,9 +151,11 @@ sub results {
 
     my $result = $self->exec;
 
-    my @ver_results = $result =~ /[Pp]erl-\d\.\d+\.\d+.*?Result:\s+\w+\n/gs;
+    $log->_7($result);
 
-    $log->_7("got " . scalar @ver_results . " results");
+    my @ver_results = $result =~ /[Pp]erl-\d\.\d+\.\d+.*?(?:Successfully tested .*?\n|FAIL\n)/gs;
+
+    $log->_6("got " . scalar @ver_results . " results");
 
     my @pass;
     my $fail = 0;
@@ -166,9 +168,9 @@ sub results {
         }
         my $res;
 
-        if (/Result:\s+(PASS)/){
+        if (/Successfully tested /){
             $log->_7("$ver PASSED...");
-            $res = $1;
+            $res = 'PASS';
         }
         else {
             $log->_7("$ver FAILED...");
@@ -177,16 +179,17 @@ sub results {
             last;
         }
 
-        $log->_7("$ver :: $res");
+        $log->_6("$ver :: $res");
         push @pass, "$ver :: $res\n";
     }
 
     if (! $fail) {
         print "\n";
+        print "$self->{args}{plugin_arg}\n" if $self->{args}{plugin_arg};
         print $_ for @pass;
     }
 
-    $log->_7(__PACKAGE__ ." run finished");
+    $log->_6(__PACKAGE__ ." run finished");
 }
 sub run {
     my $self = shift;
@@ -194,7 +197,7 @@ sub run {
     my $new = defined $self->{args}{new} ? $self->{args}{new} : 0;
 
     my $log = $log->child('run');
-    $log->_7("commencing run()");
+    $log->_6("commencing run()");
 
     my $brew_info = $self->brew_info;
 
@@ -224,7 +227,6 @@ sub run {
     else {
         $self->results();
     }
-
 }
 sub exec {
     my $self = shift;
@@ -237,10 +239,17 @@ sub exec {
     my $fname = $wfh->filename;
 
     $log->_7("temp filename: $fname");
-    $log->_7("fetching instructions from the plugin");
-    $log->_7("instructions to be executed:");
+    if ($self->{args}{plugin_arg}) {
+        $log->_6( "fetching instructions from the plugin with arg $self->{args}{plugin_arg}" );
+    }
+    
+    my @exec_cmd = $self->{exec_plugin}->(
+        __PACKAGE__,
+        $self->log,
+        $self->{args}{plugin_arg}
+    );
 
-    my @exec_cmd = $self->{exec_plugin}->();
+    $log->_7("instructions to be executed:\n" . join ', ', @exec_cmd);
 
     for (@exec_cmd){
         $log->_7($_);
@@ -254,8 +263,8 @@ sub exec {
 
     if ($self->{args}{on}){
         my $vers = join ',', @{ $self->{args}{on} };
-        $log->_7("versions to run on: $vers");
-        $log->_7("exec'ing: $brew exec --with $vers perl $fname");
+        $log->_6("versions to run on: $vers");
+        $log->_6("exec'ing: $brew exec --with $vers perl $fname");
 
         if ($bcmd->is_win){
             return `$brew exec --with $vers perl $fname 2>nul`;
@@ -266,7 +275,7 @@ sub exec {
         }
     }
     else {
-        $log->_7("exec'ing: $brew exec perl $fname");
+        $log->_6("exec'ing: $brew exec perl $fname");
 
         if ($bcmd->is_win) {
             return `$brew exec perl $fname 2>nul`;
@@ -297,11 +306,10 @@ sub _create_log {
 
     $self->{log}->_7("in _create_log()");
 
-    if (defined $level && $level < 6){
+    if ($self->{log}->level < 6){
         $self->{log}->display(0);
         $self->{log}->custom_display("-");
-        $self->{log}->_7("setting log level to $level");
-        $self->{log}->_7("log object created with level $level");
+        $self->{log}->_6("set log level to " . defined $level ? $level : 4);
     }
 
     return $self->{log};
@@ -319,7 +327,8 @@ sub is_win {
 
 =head1 NAME
 
-Test::BrewBuild - Backend module for the L<brewbuild> command-line program.
+Test::BrewBuild - Perl/Berry brew unit testing automation across installed perl
+versions (Windows and Unix).
 
 =for html
 <a href="http://travis-ci.org/stevieb9/p5-test-brewbuild"><img src="https://secure.travis-ci.org/stevieb9/p5-test-brewbuild.png"/>
