@@ -2,9 +2,14 @@ package Test::BrewBuild::Plugin::DefaultExec;
 
 # default exec command set plugin for Test::BrewBuild
 
-our $VERSION = '0.06';
+our $VERSION = '1.03';
 
 sub brewbuild_exec {
+    shift; # throw away the class
+    my $log = shift;
+    my $clog = $log->child( __PACKAGE__.'::brewbuild_exec' );
+    $clog->_6( 'performing plugin duties' );
+
     return <DATA>;
 }
 
@@ -16,11 +21,7 @@ sub brewbuild_exec {
 
 Test::BrewBuild::Plugin::DefaultExec - The default 'exec' command plugin.
 
-=head1 DESCRIPTION
-
-To create a temporary or test plugin, simply create a C<*.pm> file just like
-this one with the same subroutine, and in the C<__DATA__> section, include the
-code you need executed by C<*brew exec>.
+=head1 SYNOPSIS
 
 To use, if you've actually installed your plugin:
 
@@ -31,6 +32,22 @@ relative):
 
     berrybrew --plugin /path/to/ExecPlugin.pm
 
+Send in arguments to your plugin. The C<--args, -a> flag sets an array. For
+each argument, C<brewbuild> is called once, passing in the next element of the
+array.
+
+    berrybrew -p My::Plugin --args 1 -a 2
+
+=head1 CREATION
+
+To create a temporary or test plugin, simply create a C<*.pm> file just like
+this one with the same subroutine, and in the C<__DATA__> section, include the
+code you need executed by C<*brew exec>.
+
+The first argument you will receive is the C<Logging::Simple> log object of
+the core C<Test::BrewBuild>. You can ignore this, or create a child and log
+throughout your plugin.
+
 =head1 AUTHOR
 
 Steve Bertrand, C<< <steveb at cpan.org> >>
@@ -38,11 +55,4 @@ Steve Bertrand, C<< <steveb at cpan.org> >>
 =cut
 
 __DATA__
-if ($^O eq 'MSWin32'){
-    my $make = -e 'Makefile.PL' ? 'dmake' : 'Build';
-    system "cpanm --installdeps . && $make && $make test";
-}
-else {
-    my $make = -e 'Makefile.PL' ? 'make' : './Build';
-    system "cpanm --installdeps . && $make && $make test";
-}
+system "cpanm --installdeps . && cpanm --test-only .";
